from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ("qol", "قول"),
    ("bax", "باش"),
    ("put", "پۇت"),
    ("kOz", "كۆز"),
    ("wAdA", "ۋەدە"),
    ("juda", "جۇدا"),
    ("sAn", "سەن"),
    ("samsaq", "سامساق"),
    ("haywan", "ھايۋان"),
    ("xir", "شىر"),
    ("Gulja", "غۇلجا"),
    ("kitab", "كىتاب"),
    ("wAtAn", "ۋەتەن"),
    ("tomur", "تومۇر"),
    ("kOmUr", "كۆمۈر"),
    ("asman", "ئاسمان"),
    ("muAllim", "مۇئەللىم"),
    ("sincay", "سىنچاي"),
    ("anar", "ئانار"),
    ("vAnjur", "ئەنجۇر"),
    ("orda", "ئوردا"),
    ("urux", "ئۇرۇش"),
    ("OrdAk", "ئۆردەك"),
    ("UzUm", "ئۈزۈم"),
    ("elan", "ئېلان"),
    ("inkas", "ئىنكاس"),
    ("ana", "ئانا"),
    ("bizniN muAllim", "بىزنىڭ مۇئەللىم"),
    ("uzun sApAr", "ئۇزۇن سەپەر"),
    ("mAktAp mudir", "مەكتەپ مۇدىر"),
    ("yoGan bax", "يوغان باش"),
    ("maymun", "مايمۇن"),
    ("bayraq", "بايراق"),
    ("bArkAtlik", "بەركەتلىك"),
    ("poyuz", "پويۇز"),
    ("bizniN Oy", "بىزنىڭ ئۆي"),
    ("kUnlAr", "كۈنلەر"),
    ("bayramlar", "بايراملار"),
    ("tirixcan", "تىرىشچان"),
    ("yalGuz", "يالغۇز"),
    ("bir kuni", "بىر كۇنى"),
    ("balaN azsa ah urma yol tapidu bir kuni",
     "بالاڭ ئازسا ئاھ ئۇرما يول تاپىدۇ بىر كۇنى"),
    ("aman bolsa ularmu pul tapidu bir kuni",
     "ئامان بولسا ئۇلارمۇ پۇل تاپىدۇ بىر كۇنى"),
    ("Hata basqan qAdAmlAr qaldurGanda qAdAmdin",
     "خاتا باسقان قەدەملەر قالدۇرغاندا قەدەمدىن"),
    ("Ozi maNGan catqalGa ot yaqidu bir kuni",
     "ئۆزى ماڭغان چاتقالغا ئوت ياقىدۇ بىر كۇنى"),
    ("gAdAnkAxlik hickimdin udum AmAs ularGa",
     "گەدەنكەشلىك ھىچكىمدىن ئۇدۇم ئەمەس ئۇلارغا"),
    ("Ozi kilip aldiNGa gAp acidu bir kuni",
     "ئۆزى كىلىپ ئالدىڭغا گەپ ئاچىدۇ بىر كۇنى"),
    ("at bolGicA asawtay hAryan cipip baqmaydu",
     "ئات بولغىچە ئاساۋتاي ھەريان چىپىپ باقمايدۇ"),
    ("ularGimu bu dunya yUk artidu bir kuni",
     "ئۇلارغىمۇ بۇ دۇنيا يۈك ئارتىدۇ بىر كۇنى"),
]


@pytest.mark.parametrize("input,expected", test_data)
def test_CTS2UAS(input, expected):
    converter = UgMultiScriptConverter("XJUS", "UAS")
    assert converter(input) == expected
